export default {
    "message": "Cannot use 'await' as identifier inside an async function",
    "column": 20,
    "index": 19,
    "lineNumber": 1
}
